@@ -2,7 +2,7 @@
 
 # https://github.com/billythegoat356 https://github.com/loTus04
 
-# Version : 0.5 BETA
+# Version : 0.8 BETA
 
 # based on pyfade anc pycenter, R.I.P
 
@@ -200,6 +200,7 @@ class Colors:
 
     white = _MakeColors._start('255;255;255')
     black = _MakeColors._start('0;0;0')
+    gray = _MakeColors._start('150;150;150')
 
     yellow = _MakeColors._start('255;255;0')
     purple = _MakeColors._start('255;0;255')
@@ -209,18 +210,16 @@ class Colors:
     pink = _MakeColors._start('255;0;150')
     turquoise = _MakeColors._start('0;150;255')
 
-    gray = _MakeColors._start('150;150;150')
-
     light_gray = _MakeColors._start('200;200;200')
     dark_gray = _MakeColors._start('100;100;100')
 
     light_red = _MakeColors._start('255;100;100')
-    light_green = _MakeColors._start('100;100;255')
-    light_blue = _MakeColors._start('100;255;100')
+    light_green = _MakeColors._start('100;255;100')
+    light_blue = _MakeColors._start('100;100;255')
 
     dark_red = _MakeColors._start('100;0;0')
-    dark_green = _MakeColors._start('0;0;100')
-    dark_blue = _MakeColors._start('0;100;0')
+    dark_green = _MakeColors._start('0;100;0')
+    dark_blue = _MakeColors._start('0;0;100')
 
     reset = white
 
@@ -298,14 +297,12 @@ class Colors:
 
     static_colors = [
         red, green, blue,
-        black, white,
+        white, black, gray,
         yellow, purple, cyan,
-        gray,
         orange, pink, turquoise,
         light_gray, dark_gray,
-        light_red, dark_red,
-        light_green, dark_green,
-        light_blue, dark_blue,
+        light_red, light_green, light_blue,
+        dark_red, dark_green, dark_blue,
         reset
     ]
 
@@ -667,13 +664,19 @@ class Center:
     """ ! developper area ! """
 
     def _xspaces(var: str):
-        col = _terminal_size().columns
-        varl = var.splitlines()
-        nvarl = max(len(v) for v in varl if v.strip())
-        return int((col - nvarl) / 2)
+        try:
+            col = _terminal_size().columns
+        except OSError:
+            return 0
+            varl = var.splitlines()
+            nvarl = max(len(v) for v in varl if v.strip())
+            return int((col - nvarl) / 2)
 
     def _yspaces(var: str):
-        lin = _terminal_size().lines
+        try:
+            lin = _terminal_size().lines
+        except OSError:
+            return 0
         varl = var.splitlines()
         nvarl = len(varl)
         return int((lin - nvarl) / 2)
@@ -763,6 +766,23 @@ class Box:
         Lines()                       |             create a text framed by two lines
 
     """
+
+    def Box(content: str, up_left: str, up_right: str, down_left: str, down_right: str, left_line: str, up_line: str, right_line: str, down_line: str) -> str:
+        l = 0
+        lines = content.splitlines()
+        for a in lines:
+            if len(a) > l:
+                l = len(a)
+        if l % 2 == 1:
+            l += 1
+        box = up_left + (up_line * l) + up_right + "\n"
+        #box += "║ " + (" " * int(l / 2)) + (" " * int(l / 2)) + " ║\n"
+        for line in lines:
+            box += left_line + " " + line + (" " * int((l - len(line)))) + " " + right_line + "\n"
+        box += down_left + (down_line * l) + down_right + "\n"
+        return box
+
+
     def SimpleCube(content: str) -> str:
         l = 0
         lines = content.splitlines()
@@ -780,18 +800,7 @@ class Box:
         return box
 
     def DoubleCube(content: str) -> str:
-        l = 0
-        lines = content.splitlines()
-        for a in lines:
-            if len(a) > l:
-                l = len(a)
-        if l % 2 == 1:
-            l += 1
-        box = "╔═" + ("═" * l) + "═╗\n"
-        #box += "║ " + (" " * int(l / 2)) + (" " * int(l / 2)) + " ║\n"
-        for line in lines:
-            box += "║ " + line + (" " * int((l - len(line)))) + " ║\n"
-        box += "╚═" + ("═" * l) + "═╝\n"
+        return Box.Box(content, "╔═", "═╗", "╚═", "═╝", "║", "═", "║", "═")
 
     def Lines(content: str) -> str:
         # voir pour ajouter un argument pour personnaliser la ligne
